package net.knarcraft.ffmpegconverter.converter;

import net.knarcraft.ffmpegconverter.streams.StreamObject;
import net.knarcraft.ffmpegconverter.utility.FFMpegHelper;

import java.io.File;
import java.util.List;

/**
 * A converter for converting video files
 */
public class VideoConverter extends AbstractConverter {

    /**
     * Instantiates a new video converter
     *
     * @param ffprobePath  <p>Path/command to ffprobe.</p>
     * @param ffmpegPath   <p>Path/command to ffmpeg.</p>
     * @param newExtension <p>The extension of the new file.</p>
     */
    public VideoConverter(String ffprobePath, String ffmpegPath, String newExtension) {
        super(newExtension);
        this.ffprobePath = ffprobePath;
        this.ffmpegPath = ffmpegPath;
    }

    @Override
    public String[] generateConversionCommand(String executable, File file, List<StreamObject> streams, String outFile) {
        List<String> command = FFMpegHelper.getFFMpegGeneralFileCommand(executable, file.getName());
        if (this.debug) {
            FFMpegHelper.addDebugArguments(command, 50, 120);
        }

        //Add all streams without re-encoding
        command.add("-map");
        command.add("0");
        command.add("-c");
        command.add("copy");

        command.add(outFile);
        return command.toArray(new String[0]);
    }

    @Override
    public String[] getValidFormats() {
        return videoFormats;
    }

}